@@ -12,32 +12,26 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from copy import deepcopy
+from logging import getLogger
 from pathlib import Path
 from typing import List, Tuple, Optional, Generator, Union
-from logging import getLogger
-from copy import deepcopy
 
 import numpy as np
-import keras.metrics
-import keras.optimizers
-from keras import backend as K
-from keras.layers import Dense, Input
-from keras.layers import concatenate, Activation, Concatenate, Reshape
-from keras.layers.convolutional import Conv1D
-from keras.layers.core import Dropout
-from keras.layers.normalization import BatchNormalization
-from keras.layers.pooling import GlobalMaxPooling1D, MaxPooling1D, GlobalAveragePooling1D
-from keras.layers.recurrent import LSTM, GRU
-from keras.layers.wrappers import Bidirectional
-from keras.models import Model
-from keras.regularizers import l2
+import tensorflow.keras
 from overrides import overrides
+from tensorflow.keras import backend as K
+from tensorflow.keras.layers import (Conv1D, Dropout, Dense, Input, BatchNormalization, GlobalMaxPooling1D,
+                                     MaxPooling1D, concatenate, Activation, Reshape,
+                                     GlobalAveragePooling1D, LSTM, GRU, Bidirectional)
+from tensorflow.keras.models import Model
+from tensorflow.keras.regularizers import l2
 
 from deeppavlov.core.common.errors import ConfigError
 from deeppavlov.core.common.file import save_json, read_json
 from deeppavlov.core.common.registry import register
-from deeppavlov.core.models.keras_model import LRScheduledKerasModel
 from deeppavlov.core.layers.keras_layers import additive_self_attention, multiplicative_self_attention
+from deeppavlov.core.models.keras_model import LRScheduledKerasModel
 
 log = getLogger(__name__)
 
@@ -117,6 +111,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
                      **kwargs}
         self.opt = deepcopy(given_opt)
         self.model = None
+        self.optimizer = None
 
         super().__init__(**given_opt)
 
@@ -125,7 +120,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
 
         self.n_classes = self.opt.get('n_classes')
         if self.n_classes == 0:
-            raise ConfigError("Please, provide vocabulary with considered intents.")
+            raise ConfigError("Please, provide vocabulary with considered classes.")
 
         self.load()
 
@@ -148,14 +143,14 @@ class KerasClassificationModel(LRScheduledKerasModel):
             array of embedded texts
         """
         pad = np.zeros(self.opt['embedding_size'])
-        cutted_batch = [sen[:self.opt['text_size']] for sen in sentences]
+        cut_batch = [sen[:self.opt['text_size']] for sen in sentences]
         if self.opt["padding"] == "pre":
-            cutted_batch = [[pad] * (self.opt['text_size'] - len(tokens)) + list(tokens) for tokens in cutted_batch]
+            cut_batch = [[pad] * (self.opt['text_size'] - len(tokens)) + list(tokens) for tokens in cut_batch]
         elif self.opt["padding"] == "post":
-            cutted_batch = [list(tokens) + [pad] * (self.opt['text_size'] - len(tokens)) for tokens in cutted_batch]
+            cut_batch = [list(tokens) + [pad] * (self.opt['text_size'] - len(tokens)) for tokens in cut_batch]
         else:
             raise ConfigError("Padding type {} is not acceptable".format(self.opt['padding']))
-        return np.asarray(cutted_batch)
+        return np.asarray(cut_batch)
 
     def check_input(self, texts: List[List[np.ndarray]]) -> np.ndarray:
         """
@@ -193,43 +188,20 @@ class KerasClassificationModel(LRScheduledKerasModel):
         metrics_values = self.model.train_on_batch(features, np.array(labels))
         return metrics_values
 
-    def infer_on_batch(self, texts: List[List[np.ndarray]], labels: list = None) -> \
-            Union[float, List[float], np.ndarray]:
-        """
-        Infer the model on the given batch
-
-        Args:
-            texts: list of tokenized embedded text samples
-            labels: list of labels
-
-        Returns:
-            metrics values on the given batch, if labels are given
-            predictions, otherwise
-        """
-        features = self.check_input(texts)
-
-        if labels:
-            metrics_values = self.model.test_on_batch(features, np.array(labels))
-            return metrics_values
-        else:
-            predictions = self.model.predict(features)
-            return predictions
-
-    def __call__(self, data: List[List[np.ndarray]], *args) -> List[List[float]]:
+    def __call__(self, data: List[List[np.ndarray]]) -> List[List[float]]:
         """
         Infer on the given data
 
         Args:
             data: list of tokenized text samples
-            *args: additional arguments
 
         Returns:
             for each sentence:
                 vector of probabilities to belong with each class
                 or list of labels sentence belongs with
         """
-        preds = np.array(self.infer_on_batch(data), dtype="float64").tolist()
-        return preds
+        features = self.check_input(data)
+        return self.model.predict(features)
 
     def init_model_from_scratch(self, model_name: str) -> Model:
         """
@@ -284,7 +256,8 @@ class KerasClassificationModel(LRScheduledKerasModel):
                 try:
                     model.load_weights(str(weights_path))
                 except ValueError:
-                    raise ConfigError("Some non-changable parameters of neural network differ from given pre-trained model")
+                    raise ConfigError("Some non-changeable parameters of neural network differ"
+                                      " from given pre-trained model")
 
                 self.model = model
 
@@ -313,7 +286,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
         Returns:
 
         """
-        optimizer_func = getattr(keras.optimizers, optimizer_name, None)
+        optimizer_func = getattr(tensorflow.keras.optimizers, optimizer_name, None)
         if callable(optimizer_func):
             if isinstance(learning_rate, float) and isinstance(learning_rate_decay, float):
                 # in this case decay will be either given in config or, by default, learning_rate_decay=0.
@@ -321,9 +294,9 @@ class KerasClassificationModel(LRScheduledKerasModel):
             else:
                 self.optimizer = optimizer_func()
         else:
-            raise AttributeError("Optimizer {} is not defined in `keras.optimizers`".format(optimizer_name))
+            raise AttributeError("Optimizer {} is not defined in `tensorflow.keras.optimizers`".format(optimizer_name))
 
-        loss_func = getattr(keras.losses, loss_name, None)
+        loss_func = getattr(tensorflow.keras.losses, loss_name, None)
         if callable(loss_func):
             loss = loss_func
         else:
@@ -377,14 +350,15 @@ class KerasClassificationModel(LRScheduledKerasModel):
         # then change load_path to save_path for config
         self.opt["epochs_done"] = self.epochs_done
         if isinstance(self.opt.get("learning_rate", None), float):
-            self.opt["final_learning_rate"] = K.eval(self.optimizer.lr) / (1. +
-                                                                           K.eval(self.optimizer.decay) * self.batches_seen)
+            self.opt["final_learning_rate"] = (K.eval(self.optimizer.lr) /
+                                               (1. + K.eval(self.optimizer.decay) * self.batches_seen))
 
         if self.opt.get("load_path") and self.opt.get("save_path"):
             if self.opt.get("save_path") != self.opt.get("load_path"):
                 self.opt["load_path"] = str(self.opt["save_path"])
         save_json(self.opt, opt_path)
 
+    # noinspection PyUnusedLocal
     def cnn_model(self, kernel_sizes_cnn: List[int], filters_cnn: int, dense_size: int,
                   coef_reg_cnn: float = 0., coef_reg_den: float = 0., dropout_rate: float = 0.,
                   input_projection_size: Optional[int] = None, **kwargs) -> Model:
@@ -438,6 +412,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
         model = Model(inputs=inp, outputs=act_output)
         return model
 
+    # noinspection PyUnusedLocal
     def dcnn_model(self, kernel_sizes_cnn: List[int], filters_cnn: List[int], dense_size: int,
                    coef_reg_cnn: float = 0., coef_reg_den: float = 0., dropout_rate: float = 0.,
                    input_projection_size: Optional[int] = None, **kwargs) -> Model:
@@ -488,6 +463,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
         model = Model(inputs=inp, outputs=act_output)
         return model
 
+    # noinspection PyUnusedLocal
     def cnn_model_max_and_aver_pool(self, kernel_sizes_cnn: List[int], filters_cnn: int, dense_size: int,
                                     coef_reg_cnn: float = 0., coef_reg_den: float = 0., dropout_rate: float = 0.,
                                     input_projection_size: Optional[int] = None, **kwargs) -> Model:
@@ -527,7 +503,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
             output_i = Activation('relu')(output_i)
             output_i_0 = GlobalMaxPooling1D()(output_i)
             output_i_1 = GlobalAveragePooling1D()(output_i)
-            output_i = Concatenate()([output_i_0, output_i_1])
+            output_i = concatenate([output_i_0, output_i_1])
             outputs.append(output_i)
 
         output = concatenate(outputs, axis=1)
@@ -545,6 +521,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
         model = Model(inputs=inp, outputs=act_output)
         return model
 
+    # noinspection PyUnusedLocal
     def bilstm_model(self, units_lstm: int, dense_size: int,
                      coef_reg_lstm: float = 0., coef_reg_den: float = 0.,
                      dropout_rate: float = 0., rec_dropout_rate: float = 0.,
@@ -592,6 +569,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
         model = Model(inputs=inp, outputs=act_output)
         return model
 
+    # noinspection PyUnusedLocal
     def bilstm_bilstm_model(self, units_lstm_1: int, units_lstm_2: int, dense_size: int,
                             coef_reg_lstm: float = 0., coef_reg_den: float = 0.,
                             dropout_rate: float = 0., rec_dropout_rate: float = 0.,
@@ -648,6 +626,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
         model = Model(inputs=inp, outputs=act_output)
         return model
 
+    # noinspection PyUnusedLocal
     def bilstm_cnn_model(self, units_lstm: int, kernel_sizes_cnn: List[int], filters_cnn: int, dense_size: int,
                          coef_reg_lstm: float = 0., coef_reg_cnn: float = 0., coef_reg_den: float = 0.,
                          dropout_rate: float = 0., rec_dropout_rate: float = 0.,
@@ -699,7 +678,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
             output_i = GlobalMaxPooling1D()(output_i)
             outputs.append(output_i)
 
-        output = Concatenate(axis=1)(outputs)
+        output = concatenate(outputs, axis=1)
         output = Dropout(rate=dropout_rate)(output)
         output = Dense(dense_size, activation=None,
                        kernel_regularizer=l2(coef_reg_den))(output)
@@ -711,6 +690,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
         model = Model(inputs=inp, outputs=act_output)
         return model
 
+    # noinspection PyUnusedLocal
     def cnn_bilstm_model(self, kernel_sizes_cnn: List[int], filters_cnn: int, units_lstm: int, dense_size: int,
                          coef_reg_cnn: float = 0., coef_reg_lstm: float = 0., coef_reg_den: float = 0.,
                          dropout_rate: float = 0., rec_dropout_rate: float = 0.,
@@ -775,6 +755,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
         model = Model(inputs=inp, outputs=act_output)
         return model
 
+    # noinspection PyUnusedLocal
     def bilstm_self_add_attention_model(self, units_lstm: int, dense_size: int, self_att_hid: int, self_att_out: int,
                                         coef_reg_lstm: float = 0., coef_reg_den: float = 0.,
                                         dropout_rate: float = 0., rec_dropout_rate: float = 0.,
@@ -828,6 +809,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
         model = Model(inputs=inp, outputs=act_output)
         return model
 
+    # noinspection PyUnusedLocal
     def bilstm_self_mult_attention_model(self, units_lstm: int, dense_size: int, self_att_hid: int, self_att_out: int,
                                          coef_reg_lstm: float = 0., coef_reg_den: float = 0.,
                                          dropout_rate: float = 0., rec_dropout_rate: float = 0.,
@@ -881,6 +863,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
         model = Model(inputs=inp, outputs=act_output)
         return model
 
+    # noinspection PyUnusedLocal
     def bigru_model(self, units_gru: int, dense_size: int,
                     coef_reg_lstm: float = 0., coef_reg_den: float = 0.,
                     dropout_rate: float = 0., rec_dropout_rate: float = 0.,
@@ -928,6 +911,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
         model = Model(inputs=inp, outputs=act_output)
         return model
 
+    # noinspection PyUnusedLocal
     def bigru_with_max_aver_pool_model(self, units_gru: int, dense_size: int,
                                        coef_reg_gru: float = 0., coef_reg_den: float = 0.,
                                        dropout_rate: float = 0., rec_dropout_rate: float = 0.,
@@ -962,7 +946,7 @@ class KerasClassificationModel(LRScheduledKerasModel):
         output1 = GlobalMaxPooling1D()(output)
         output2 = GlobalAveragePooling1D()(output)
 
-        output = Concatenate()([output1, output2, state1, state2])
+        output = concatenate([output1, output2, state1, state2])
 
         output = Dropout(rate=dropout_rate)(output)
         output = Dense(dense_size, activation=None,
