@@ -1,14 +1,14 @@
 import json
 from itertools import combinations
 from pathlib import Path
-from typing import Union, Dict
+from typing import Union, Dict, List, Tuple
 
 from deeppavlov.core.commands.utils import expand_path
 from deeppavlov.core.common.errors import ConfigError
 from deeppavlov.core.common.registry import register, get_model
 from deeppavlov.dataset_readers.dstc2_reader import DSTC2DatasetReader
 from deeppavlov.models.go_bot.dto.dataset_features import BatchDialoguesFeatures
-from deeppavlov.models.go_bot.nlg.dto.json_nlg_response import JSONNLGResponse
+from deeppavlov.models.go_bot.nlg.dto.json_nlg_response import JSONNLGResponse, VerboseJSONNLGResponse
 from deeppavlov.models.go_bot.nlg.nlg_manager import log
 from deeppavlov.models.go_bot.nlg.nlg_manager_interface import NLGManagerInterface
 from deeppavlov.models.go_bot.policy.dto.policy_prediction import PolicyPrediction
@@ -74,7 +74,7 @@ class MockJSONNLGManager(NLGManagerInterface):
 
     def _extract_actions_combinations(self, dataset_path: Union[str, Path]):
         dataset_path = expand_path(dataset_path)
-        dataset = self._dataset_reader.read(data_path=dataset_path, dialogs=True)
+        dataset = self._dataset_reader.read(data_path=dataset_path, dialogs=True, ignore_slots=True)
         actions_combinations = set()
         for dataset_split in dataset.values():
             for dialogue in dataset_split:
@@ -96,7 +96,7 @@ class MockJSONNLGManager(NLGManagerInterface):
                       f"initialized actions2slots mapping with an empty one: {str(actions2slots)}")
         return actions2slots
 
-    def get_action_id(self, action_text: str) -> int:
+    def get_action_id(self, action_text: Union[str, Tuple[str, ...]]) -> int:
         """
         Looks up for an ID corresponding to the passed action text.
 
@@ -105,8 +105,10 @@ class MockJSONNLGManager(NLGManagerInterface):
         Returns:
             an ID corresponding to the passed action text
         """
-
-        actions_tuple = tuple(action_text.split('+'))
+        if isinstance(action_text, str):
+            actions_tuple = tuple(action_text.split('+'))
+        else:
+            actions_tuple = action_text
         return self.action_tuples2ids[actions_tuple]  # todo unhandled exception when not found
 
     def decode_response(self,
@@ -129,7 +131,10 @@ class MockJSONNLGManager(NLGManagerInterface):
         slots_values = {slot_name: tracker_slotfilled_state.get(slot_name, "unk") for slot_name in slots_to_log}
         actions_tuple = self.ids2action_tuples[policy_prediction.predicted_action_ix]
 
-        return JSONNLGResponse(slots_values, actions_tuple)
+        response = JSONNLGResponse(slots_values, actions_tuple)
+        verbose_response = VerboseJSONNLGResponse.from_json_nlg_response(response)
+        verbose_response.policy_prediction = policy_prediction
+        return verbose_response
 
     def num_of_known_actions(self) -> int:
         """
@@ -137,3 +142,10 @@ class MockJSONNLGManager(NLGManagerInterface):
             the number of actions known to the NLG module
         """
         return len(self.action_tuples2ids.keys())
+
+    def known_actions(self) -> List:
+        """
+        Returns:
+             the list of actions known to the NLG module
+        """
+        return list(self.action_tuples2ids.keys())
